package com.diagbot.repository;

import com.diagbot.entity.node.EntityBaseInfo;
import com.diagbot.entity.node.EntityInfo;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.neo4j.annotation.Query;
import org.springframework.data.neo4j.repository.Neo4jRepository;
import org.springframework.data.repository.query.Param;

import java.util.List;

/**
 * @Description:
 * @Author:zhaops
 * @time: 2020/12/14 13:26
 */
public interface EntityInfoRepository extends Neo4jRepository<EntityBaseInfo,Long> {
    @Query(value = "with {labels} as nlabels\n" +
            "match(n)\n" +
            "where any(label in labels(n) where label in nlabels)\n" +
            "and (case when {name} is not null and {name} <> '' " +
            "then " +
            "((toLower(n.`name`) CONTAINS toLower($name) OR toLower(n.`拼音编码`) CONTAINS toLower($name))) " +
            "else 1 = 1 " +
            "end ) \n" +
            "and (case when {status} is not null " +
            "then " +
            "n.状态 = {status} " +
            "else 1 = 1 " +
            "end ) \n" +
            "and (case when {is_kl} is not null " +
            "then " +
            "n.静态知识标识 = {is_kl} " +
            "else 1 = 1 " +
            "end ) \n" +
            "return id(n) as id,n.name as name,n.拼音编码  as pycode,labels(n)[0] as labelType,n.状态 as status,n.静态知识标识 as is_kl\n" +
            "order by n.状态 desc, id(n) desc",
            countQuery = "with {labels} as nlabels\n" +
                    "match(n)\n" +
                    "where any(label in labels(n) where label in nlabels)\n" +
                    "and (case when {name} is not null and {name} <> '' " +
                    "then " +
                    "((toLower(n.`name`) CONTAINS toLower($name) OR toLower(n.`拼音编码`) CONTAINS toLower($name))) " +
                    "else 1 = 1 " +
                    "end ) \n" +
                    "and (case when {status} is not null " +
                    "then " +
                    "n.状态 = {status} " +
                    "else 1 = 1 " +
                    "end ) \n" +
                    "and (case when {is_kl} is not null " +
                    "then " +
                    "n.静态知识标识 = {is_kl} " +
                    "else 1 = 1 " +
                    "end ) \n" +
                    "return count(*)")
    Page<EntityInfo> getEntityPage(@Param("labels") List<String> labels,
                                   @Param("name") String name,
                                   @Param("status") Integer status,
                                   @Param("is_kl") Integer is_kl,
                                   Pageable pageable);

    @Query(value = "match(n) where n.name={name} and {label} in labels(n) \n " +
            "return count(*)")
    Integer existNodes(@Param("name") String name,
                                @Param("label") String label);
}